/** Collectable.h
 *
 * @author Hans de Ruiter
 *
 * @copyright (c) 2023 by Kea Sigma Delta Limited, all rights reserved
 *
 * See License.txt for license.
 */

#pragma once

#include "Actor.h"
#include "PhysicsObject.h"

#include <memory>

#include "TextureAtlas.h"

typedef enum CollectableState {
    CS_AVAILABLE, // Available in the world
    CS_COLLECTING, // Being collected
    CS_COLLECTED // Collected
} CollectableState;

/** Represents a collectable object.
 * A collectable is an item that the player can collect (e.g., coins).
 * 
 * Collectables have the following possible animations:
 * - default - when the collectable is in the world
 * - collect - played when a player "collects" (i.e., picks up or takes) the item
 * 
 * To make a collectable, add at least a default animation to a texture atlas. It must
 * have at least one frame. Ensure that the object's origin is in its centre.
 */
class Collectable : public Actor {
public:
    /** Constructs a new collectable object.
     * 
     * @param typeName the type of colletable
     * @param atlasFileName the 
     */
    Collectable(const char *typeName, const char *atlasFileName);

    virtual ~Collectable();

    // ##### FIXME! ###### collect() method

    bool update(float elapsedTime) override;

    void draw(float worldScale) override;
    
    void createPhysicsBody(b2World &world, float worldScale, 
		const b2Vec2 &position, const b2Vec2 &velocity) override;


protected:
    CollectableState state;

    std::shared_ptr<TextureAtlas> textureAtlas;
    const TASprite *sprite;

    std::unique_ptr<TASpriteAnimationPlayer> defaultAnimPlayer;
    std::unique_ptr<TASpriteAnimationPlayer> collectAnimPlayer;
    
    TASpriteAnimationPlayer *currAnimPlayer;

    PhysicsObject physicsObject;
};
